@@ -3,7 +3,7 @@ from typing import List
 from nonebot.rule import Rule
 from nonebot.plugin import on_message, on_regex
 from nonebot.adapters.onebot.v11 import Bot, Event, Message, MessageSegment, GroupMessageEvent
-import aiohttp, re, os, random, cv2, asyncio, base64, json
+import aiohttp, re, os, random, cv2, asyncio, base64
 
 global_config = nonebot.get_driver().config
 config = global_config.dict()
@@ -19,23 +19,24 @@ headersCook = {
 if pixiv_cookies:
     headersCook['cookie'] = pixiv_cookies
 
-pixiv_r18 = config.get('pixiv_r18')
-if not pixiv_r18:
-    pixiv_r18 = True
-if pixiv_r18 and ( pixiv_r18 == 'True' or pixiv_r18 == 'False'):
-    pixiv_r18 = eval(pixiv_r18)
-elif pixiv_r18:
+PIXIV_R18 = config.get('pixiv_r18', 'True')
+if PIXIV_R18 and (PIXIV_R18 == 'True' or PIXIV_R18 == 'False'):
+    PIXIV_R18 = eval(PIXIV_R18)
+elif PIXIV_R18:
     try:
-        pixiv_r18 = eval(pixiv_r18)
-        if not isinstance(pixiv_r18,list):
+        PIXIV_R18 = eval(PIXIV_R18)
+        if not isinstance(PIXIV_R18, list):
             print("配置错误！！pixiv_r18应该是列表")
         else:
-            for x in pixiv_r18:
-                if not(isinstance(x,int) or (isinstance(x,str) and str(x).isdigit())):
+            for x in PIXIV_R18:
+                if not (isinstance(x, int) or (isinstance(x, str) and str(x).isdigit())):
                     print("配置错误！！pixiv_r18中应该是int类型或者str的数值类型")
+        PIXIV_R18 = [int(_) for _ in PIXIV_R18]
     except:
         print("配置错误！！")
-    
+
+BAN_PIXIV_R18 = eval(config.get('ban_pixiv_r18', '[]'))
+BAN_PIXIV_R18 = [int(_) for _ in BAN_PIXIV_R18]
 
 pathHome = f"{imgRoot}QQbotFiles/pixiv"
 if not os.path.exists(pathHome):
@@ -45,6 +46,7 @@ pathZipHome = f"{imgRoot}QQbotFiles/pixivZip"
 if not os.path.exists(pathZipHome):
     os.makedirs(pathZipHome)
 
+
 def isPixivURL() -> Rule:
     async def isPixivURL_(bot: "Bot", event: "Event") -> bool:
         if event.get_type() != "message":
@@ -59,35 +61,44 @@ def isPixivURL() -> Rule:
 
 pixivURL = on_message(rule=isPixivURL())
 
-async def check_r18(bot: Bot,event : Event, pid: str)->bool:
+
+async def validate_r18(bot: Bot, event: Event, PID: str) -> bool:
     print("R18检查ing")
-    if not await pan_R18(pid):
+    if not await pan_R18(PID):
         return True
-    if isinstance(pixiv_r18,bool):
-        if (not pixiv_r18):
-            await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+    if isinstance(PIXIV_R18, bool):
+        if not PIXIV_R18:
+            await bot.send(event=event, message="不支持R18，请修改配置后操作！")
             return False
-    elif isinstance(pixiv_r18, list):
+        else:
+            if isinstance(event, GroupMessageEvent):
+                flag = any(True if str(_) == str(event.group_id) else False for _ in BAN_PIXIV_R18)
+                if flag:
+                    await bot.send(event=event, message="不支持R18，请修改配置后操作！")
+                    return False
+                return True
+    elif isinstance(PIXIV_R18, list):
         if isinstance(event, GroupMessageEvent):
-            flag = any(True if str(x) == str(event.group_id) else False for x in pixiv_r18)
+            flag = any(True if str(_) == str(event.group_id) else False for _ in PIXIV_R18)
             if not flag:
-                await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+                await bot.send(event=event, message="不支持R18，请修改配置后操作！")
             return flag
 
     return True
 
+
 @pixivURL.handle()
-async def pixivURL(bot: Bot, event: Event):
-    pid = re.findall("https://www.pixiv.net/artworks/(\d+)|illust_id=(\d+)", str(event.get_message()))
-    if pid:
-        pid = [x for x in pid[0] if x][0]
-        if not check_r18(bot,event,pid):
+async def pixiv_URL(bot: Bot, event: Event):
+    PID = re.findall("https://www.pixiv.net/artworks/(\d+)|illust_id=(\d+)", str(event.get_message()))
+    if PID:
+        PID = [x for x in PID[0] if x][0]
+        if not validate_r18(bot, event, PID):
             return
-        xx = (await checkGIF(pid))
+        xx = (await check_GIF(PID))
         if xx != "NO":
-            await GIF_send(xx, pid, event, bot)
+            await GIF_send(xx, PID, event, bot)
         else:
-            await send(pid, event, bot)
+            await send(PID, event, bot)
 
 
 pixiv = on_regex(pattern="^pixiv\ ")
@@ -95,85 +106,68 @@ pixiv = on_regex(pattern="^pixiv\ ")
 
 @pixiv.handle()
 async def pixiv_rev(bot: Bot, event: Event):
-    pid = str(event.message).strip()[6:].strip()
-    print("?????????????????????")
-    if not await check_r18(bot,event,pid):
+    PID = str(event.get_plaintext()).strip()[6:].strip()
+    if not await validate_r18(bot, event, PID):
         return
-    xx = (await checkGIF(pid))
-    print("动图判断")
+    xx = (await check_GIF(PID))
     if xx != "NO":
-        await GIF_send(xx, pid, event, bot)
+        print("是动图")
+        await GIF_send(xx, PID, event, bot)
     else:
-        await send(pid, event, bot)
+        print("不是动图")
+        await send(PID, event, bot)
 
 
 async def fetch(session, url, name):
     print("发送请求：", url)
     async with session.get(url=url, headers=headersCook, proxy=proxy_aiohttp) as response:
-        # async with session.get(url=url, headers=headers) as response:
-        async def fetch(session, url, name):
-            print("发送请求：", url)
-            async with session.get(url=url, headers=headersCook, proxy=proxy_aiohttp) as response:
-                # async with session.get(url=url, headers=headers) as response:
-                code = response.status
-                if code == 200:
-                    content = await response.content.read()
-                    with open(f"{imgRoot}QQbotFiles/pixiv/" + name, mode='wb') as f:
-                        f.write(content)
-                    return True
-                return False
+        code = response.status
+        if code == 200:
+            content = await response.content.read()
+            with open(f"{imgRoot}QQbotFiles/pixiv/" + name, mode='wb') as f:
+                f.write(content)
+            return True
+        return False
 
 
 async def main(PID):
-    # url = f"https://www.pixiv.net/artworks/{PID}"
-    url = f"https://api.obfs.dev/api/pixiv/illust?id={PID}"
+    url = f"https://www.pixiv.net/ajax/illust/{PID}"
     async with aiohttp.ClientSession() as session:
-        x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
-        content = await x.content.read()
-        content = json.loads(content)
-        # down_url = re.findall('"original":"(.*?)\.(png|jpg|jepg)"', content.json())
+        resp = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
+        content = await resp.json()
+        # print(content)
         if content.get('error'):
             return
-        url = content.get('illust').get('meta_single_page')
-        if url:
-            url = url.get('original_image_url')
-        else:
-            url = content.get('illust').get('meta_pages')[0].get('image_urls').get('original')
-        print(url)
+        url = content.get('body').get('urls').get('original')
         name = url[url.rfind("/") + 1:]
-        hou_zhui = name.split(".")[1]
-        print(name)
-        print(hou_zhui)
+        # 后缀
+        suffix = name.split(".")[1]
         names = []
         num = 1
         if os.path.exists(f"{imgRoot}QQbotFiles/pixiv/" + name):
             while os.path.exists(f"{imgRoot}QQbotFiles/pixiv/" + name) and num <= 6:
                 names.append(name)
-                newstr = f"_p{num}.{hou_zhui}"
                 num += 1
-                name = re.sub("_p(\d+)\.(png|jpg|jepg)", newstr, name)
-                print(name)
+                name = re.sub("_p(\d+)\.(png|jpg|jepg)", f"_p{num}.{suffix}", name)
         else:
-            while (await fetch(session=session, url=url, name=name) and num <= 6):
+            while await fetch(session=session, url=url, name=name) and num <= 6:
                 names.append(name)
-                newstr = f"_p{num}.{hou_zhui}"
                 num += 1
-                url = re.sub("_p(\d+)\.(png|jpg|jepg)", newstr, url)
+                url = re.sub("_p(\d+)\.(png|jpg|jepg)", f"_p{num}.{suffix}", url)
                 name = url[url.rfind("/") + 1:]
         return names
 
 
-async def getImgsByDay(url):
+async def get_Img_ByDay(url):
     async with aiohttp.ClientSession() as session:
         if url == 'day':
             url = 'https://www.pixiv.net/ranking.php'
         else:
             url = f'https://www.pixiv.net/ranking.php?mode={url}'
-        # response = await session.get(url=url,headers=headers)
         response = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
         text = (await response.content.read()).decode()
-        imgs = set(re.findall('\<a href\=\"\/artworks\/(.*?)\"', text))
-        return list(imgs)
+        img_list = set(re.findall('\<a href\=\"\/artworks\/(.*?)\"', text))
+        return list(img_list)
 
 
 pixivRank = on_regex(pattern="^pixivRank\ ")
@@ -181,16 +175,16 @@ pixivRank = on_regex(pattern="^pixivRank\ ")
 
 @pixivRank.handle()
 async def pixiv_rev(bot: Bot, event: Event):
-    info = str(event.message).strip()[10:].strip()
+    info = str(event.get_plaintext()).strip()[10:].strip()
     dic = {
         "1": "day",
         "7": "weekly",
         "30": "monthly"
     }
     if info in dic.keys():
-        imgs = random.choices(await getImgsByDay(dic[info]), k=5)
+        img_list = random.choices(await get_Img_ByDay(dic[info]), k=5)
         names = []
-        for img in imgs:
+        for img in img_list:
             names.append(await main(img))
         if not names:
             await bot.send(event=event, message="发生了异常情况")
@@ -202,13 +196,14 @@ async def pixiv_rev(bot: Bot, event: Event):
                         path = f"{imgRoot}QQbotFiles/pixiv/{t}"
                         size = os.path.getsize(path)
                         if size // 1024 // 1024 >= 10:
-                            await yasuo(path)
+                            await ya_suo(path)
                         msg += MessageSegment.image(await base64_path(path))
             try:
                 if isinstance(event, GroupMessageEvent):
                     await send_forward_msg_group(bot, event, 'qqbot', msg)
                 else:
-                    await bot.send(event=event, message=msg)
+                    if msg:
+                        await bot.send(event=event, message=msg)
             except:
                 await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查")
     else:
@@ -222,17 +217,17 @@ async def base64_path(path: str):
     return f"base64://{ff}"
 
 
-async def send(pid: str, event: Event, bot: Bot):
-    names = await main(pid)
+async def send(PID: str, event: Event, bot: Bot):
+    names = await main(PID)
     if not names:
-        await bot.send(event=event, message="没有这个pid的图片")
+        await bot.send(event=event, message="没有这个PID的图片")
     else:
         msg = None
         for name in names:
             path = f"{imgRoot}QQbotFiles/pixiv/{name}"
             size = os.path.getsize(path)
             if size // 1024 // 1024 >= 10:
-                await yasuo(path)
+                await ya_suo(path)
             msg += MessageSegment.image(await base64_path(path))
         try:
             if isinstance(event, GroupMessageEvent):
@@ -241,36 +236,27 @@ async def send(pid: str, event: Event, bot: Bot):
                 await bot.send(event=event, message=msg)
 
         except:
-            await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查,尝试一张一张的发图片ing")
             try:
+                for name in names:
+                    path = f"{imgRoot}QQbotFiles/pixiv/{name}"
+                    os.system(f"echo '1' >> {path}")
+                msg = None
                 for name in names:
                     path = f"{imgRoot}QQbotFiles/pixiv/{name}"
                     size = os.path.getsize(path)
                     if size // 1024 // 1024 >= 10:
-                        await yasuo(path)
-                    await bot.send(event=event, message=MessageSegment.image(await base64_path(path)))
+                        await ya_suo(path)
+                    msg += MessageSegment.image(await base64_path(path))
+                if isinstance(event, GroupMessageEvent):
+                    await send_forward_msg_group(bot, event, 'qqbot', msg)
+                else:
+                    await bot.send(event=event, message=msg)
             except:
-                try:
-                    await bot.send(event=event, message="一张一张发送图片也风控了，尝试修改md5值再发送")
-                    for name in names:
-                        path = f"{imgRoot}QQbotFiles/pixiv/{name}"
-                        os.system(f"echo '1' >> {path}")
-                    msg=None
-                    for name in names:
-                        path = f"{imgRoot}QQbotFiles/pixiv/{name}"
-                        size = os.path.getsize(path)
-                        if size // 1024 // 1024 >= 10:
-                            await yasuo(path)
-                        msg += MessageSegment.image(await base64_path(path))
-                    if isinstance(event, GroupMessageEvent):
-                        await send_forward_msg_group(bot, event, 'qqbot', msg)
-                    else:
-                        await bot.send(event=event, message=msg)
-                except:
-                    await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查!!!")
+                await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查!!!")
 
 
-async def yasuo(path):
+# 压缩图片大小
+async def ya_suo(path):
     while os.path.getsize(path) // 1024 // 1024 >= 10:
         image = cv2.imread(path)
         shape = image.shape
@@ -278,33 +264,33 @@ async def yasuo(path):
         cv2.imwrite(f"{path}", res)
 
 
-async def checkGIF(pid: str) -> str:
-    url = f'https://www.pixiv.net/ajax/illust/{pid}/ugoira_meta'
+# 非动图返回 "NO", 动图返回下载地址
+async def check_GIF(PID: str) -> str:
+    url = f'https://www.pixiv.net/ajax/illust/{PID}/ugoira_meta'
     async with aiohttp.ClientSession() as session:
         if pixiv_cookies:
             headersCook['cookie'] = pixiv_cookies
-        x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
-        content = await x.json()
-        print(content)
+        resp = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
+        content = await resp.json()
         if content['error']:
             return "NO"
         return content['body']['originalSrc']
 
 
-async def GIF_send(url: str, pid: str, event: Event, bot: Bot):
-    path_pre = f"{imgRoot}QQbotFiles/pixivZip/{pid}"
-    if os.path.exists(f"{path_pre}/{pid}.gif"):
-        size = os.path.getsize(f"{path_pre}/{pid}.gif")
+async def GIF_send(url: str, PID: str, event: Event, bot: Bot):
+    path_pre = f"{imgRoot}QQbotFiles/pixivZip/{PID}"
+    if os.path.exists(f"{path_pre}/{PID}.gif"):
+        size = os.path.getsize(f"{path_pre}/{PID}.gif")
         while size // 1024 // 1024 >= 15:
-            msg = await run(f"file {path_pre}/{pid}.gif")
-            cheng = int(msg.split(" ")[-3]) // 2
+            msg = await run(f"file {path_pre}/{PID}.gif")
+            chang = int(msg.split(" ")[-3]) // 2
             kuan = int(msg.split(" ")[-1]) // 2
-            await run(f"{ffmpeg} -i {path_pre}/{pid}.gif -s {cheng}x{kuan} {path_pre}/{pid}_temp.gif")
-            await run(f"rm -rf {path_pre}/{pid}.gif")
-            await run(f"mv {path_pre}/{pid}_temp.gif {path_pre}/{pid}.gif")
-            size = os.path.getsize(f"{path_pre}/{pid}.gif")
+            await run(f"{ffmpeg} -i {path_pre}/{PID}.gif -s {chang}x{kuan} {path_pre}/{PID}_temp.gif")
+            await run(f"rm -rf {path_pre}/{PID}.gif")
+            await run(f"mv {path_pre}/{PID}_temp.gif {path_pre}/{PID}.gif")
+            size = os.path.getsize(f"{path_pre}/{PID}.gif")
         try:
-            await bot.send(event=event, message=MessageSegment.image(await base64_path(f"{path_pre}/{pid}.gif")))
+            await bot.send(event=event, message=MessageSegment.image(await base64_path(f"{path_pre}/{PID}.gif")))
         except:
             await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查")
         return
@@ -321,19 +307,19 @@ async def GIF_send(url: str, pid: str, event: Event, bot: Bot):
             await run(f"unzip -n {path_pre}.zip -d {path_pre}")
             image_list = sorted(os.listdir(f"{path_pre}"))
             await run(f"rm -rf {path_pre}.zip")
-            await run(f"{ffmpeg} -r {len(image_list)} -i {path_pre}/%06d.jpg {path_pre}/{pid}.gif -n")
+            await run(f"{ffmpeg} -r {len(image_list)} -i {path_pre}/%06d.jpg {path_pre}/{PID}.gif -n")
             # 压缩
-            size = os.path.getsize(f"{path_pre}/{pid}.gif")
+            size = os.path.getsize(f"{path_pre}/{PID}.gif")
             while size // 1024 // 1024 >= 15:
-                msg = await run(f"file {path_pre}/{pid}.gif")
-                cheng = int(msg.split(" ")[-3]) // 2
+                msg = await run(f"file {path_pre}/{PID}.gif")
+                chang = int(msg.split(" ")[-3]) // 2
                 kuan = int(msg.split(" ")[-1]) // 2
-                await run(f"{ffmpeg} -i {path_pre}/{pid}.gif -s {cheng}x{kuan} {path_pre}/{pid}_temp.gif")
-                await run(f"rm -rf {path_pre}/{pid}.gif")
-                await run(f"mv {path_pre}/{pid}_temp.gif {path_pre}/{pid}.gif")
-                size = os.path.getsize(f"{path_pre}/{pid}.gif")
+                await run(f"{ffmpeg} -i {path_pre}/{PID}.gif -s {chang}x{kuan} {path_pre}/{PID}_temp.gif")
+                await run(f"rm -rf {path_pre}/{PID}.gif")
+                await run(f"mv {path_pre}/{PID}_temp.gif {path_pre}/{PID}.gif")
+                size = os.path.getsize(f"{path_pre}/{PID}.gif")
             try:
-                await bot.send(event=event, message=MessageSegment.image(await base64_path(f"{path_pre}/{pid}.gif")))
+                await bot.send(event=event, message=MessageSegment.image(await base64_path(f"{path_pre}/{PID}.gif")))
             except:
                 await bot.send(event=event, message="查询失败, 帐号有可能发生风控，请检查")
 
@@ -365,39 +351,15 @@ async def send_forward_msg_group(
     )
 
 
-async def pan_R18(PID):
-    print("判断是不是R18")
-    url = f"https://api.obfs.dev/api/pixiv/illust?id={PID}"
+async def pan_R18(PID) -> bool:
+    url = f"https://www.pixiv.net/ajax/illust/{PID}"
     async with aiohttp.ClientSession() as session:
-        x = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
-        content = await x.content.read()
-        content = json.loads(content)
+        resp = await session.get(url=url, headers=headersCook, proxy=proxy_aiohttp)
+        content = await resp.json()
         if content.get('error'):
             return False
-        tag = content['illust']['tags'][0]['name']
-        print("tag: "+tag)
+        tag = content['body']['tags']['tags'][0]['tag']
         if tag == 'R-18':
             return True
         else:
             return False
-
-# pixivS = on_regex(pattern="^来点")
-
-
-# @pixivS.handle()
-        # x = await session.get(url="https://www.pixiv.net/ajax/search/artworks/"+str(key), headers=headersCook, proxy=proxy_aiohttp)
-        # # x = await session.get(url=url, headers=headers)
-        # content = await x.content.read()
-        # content = json.loads(content)
-        # print(content['error'])
-        # if not content['error']:
-            # if content['body']['illustManga']['data']:
-                # pid = random.choice(content['body']['illustManga']['data'])['id']
-    # if pid:
-        # xx = (await checkGIF(pid))
-        # if xx != "NO":
-            # await GIF_send(xx, pid, event, bot)
-        # else:
-            # await send(pid, event, bot)
-    # else:
-        # await bot.send(event=event,message="抱歉！没有搜索到任何内容")
